@@ -3,72 +3,103 @@
 
 # ***********************IMPORTANT NMAP LICENSE TERMS************************
 # *                                                                         *
-# * The Nmap Security Scanner is (C) 1996-2012 Insecure.Com LLC. Nmap is    *
+# * The Nmap Security Scanner is (C) 1996-2016 Insecure.Com LLC. Nmap is    *
 # * also a registered trademark of Insecure.Com LLC.  This program is free  *
 # * software; you may redistribute and/or modify it under the terms of the  *
 # * GNU General Public License as published by the Free Software            *
-# * Foundation; Version 2 with the clarifications and exceptions described  *
-# * below.  This guarantees your right to use, modify, and redistribute     *
-# * this software under certain conditions.  If you wish to embed Nmap      *
-# * technology into proprietary software, we sell alternative licenses      *
-# * (contact sales@insecure.com).  Dozens of software vendors already       *
-# * license Nmap technology such as host discovery, port scanning, OS       *
-# * detection, version detection, and the Nmap Scripting Engine.            *
+# * Foundation; Version 2 ("GPL"), BUT ONLY WITH ALL OF THE CLARIFICATIONS  *
+# * AND EXCEPTIONS DESCRIBED HEREIN.  This guarantees your right to use,    *
+# * modify, and redistribute this software under certain conditions.  If    *
+# * you wish to embed Nmap technology into proprietary software, we sell    *
+# * alternative licenses (contact sales@nmap.com).  Dozens of software      *
+# * vendors already license Nmap technology such as host discovery, port    *
+# * scanning, OS detection, version detection, and the Nmap Scripting       *
+# * Engine.                                                                 *
 # *                                                                         *
-# * Note that the GPL places important restrictions on "derived works", yet *
-# * it does not provide a detailed definition of that term.  To avoid       *
+# * Note that the GPL places important restrictions on "derivative works",  *
+# * yet it does not provide a detailed definition of that term.  To avoid   *
 # * misunderstandings, we interpret that term as broadly as copyright law   *
 # * allows.  For example, we consider an application to constitute a        *
-# * "derivative work" for the purpose of this license if it does any of the *
-# * following:                                                              *
-# * o Integrates source code from Nmap                                      *
-# * o Reads or includes Nmap copyrighted data files, such as                *
-# *   nmap-os-db or nmap-service-probes.                                    *
-# * o Executes Nmap and parses the results (as opposed to typical shell or  *
-# *   execution-menu apps, which simply display raw Nmap output and so are  *
-# *   not derivative works.)                                                *
-# * o Integrates/includes/aggregates Nmap into a proprietary executable     *
-# *   installer, such as those produced by InstallShield.                   *
-# * o Links to a library or executes a program that does any of the above   *
+# * derivative work for the purpose of this license if it does any of the   *
+# * following with any software or content covered by this license          *
+# * ("Covered Software"):                                                   *
 # *                                                                         *
-# * The term "Nmap" should be taken to also include any portions or derived *
-# * works of Nmap, as well as other software we distribute under this       *
-# * license such as Zenmap, Ncat, and Nping.  This list is not exclusive,   *
-# * but is meant to clarify our interpretation of derived works with some   *
-# * common examples.  Our interpretation applies only to Nmap--we don't     *
-# * speak for other people's GPL works.                                     *
+# * o Integrates source code from Covered Software.                         *
 # *                                                                         *
-# * If you have any questions about the GPL licensing restrictions on using *
-# * Nmap in non-GPL works, we would be happy to help.  As mentioned above,  *
-# * we also offer alternative license to integrate Nmap into proprietary    *
-# * applications and appliances.  These contracts have been sold to dozens  *
-# * of software vendors, and generally include a perpetual license as well  *
-# * as providing for priority support and updates.  They also fund the      *
-# * continued development of Nmap.  Please email sales@insecure.com for     *
-# * further information.                                                    *
+# * o Reads or includes copyrighted data files, such as Nmap's nmap-os-db   *
+# * or nmap-service-probes.                                                 *
 # *                                                                         *
-# * As a special exception to the GPL terms, Insecure.Com LLC grants        *
+# * o Is designed specifically to execute Covered Software and parse the    *
+# * results (as opposed to typical shell or execution-menu apps, which will *
+# * execute anything you tell them to).                                     *
+# *                                                                         *
+# * o Includes Covered Software in a proprietary executable installer.  The *
+# * installers produced by InstallShield are an example of this.  Including *
+# * Nmap with other software in compressed or archival form does not        *
+# * trigger this provision, provided appropriate open source decompression  *
+# * or de-archiving software is widely available for no charge.  For the    *
+# * purposes of this license, an installer is considered to include Covered *
+# * Software even if it actually retrieves a copy of Covered Software from  *
+# * another source during runtime (such as by downloading it from the       *
+# * Internet).                                                              *
+# *                                                                         *
+# * o Links (statically or dynamically) to a library which does any of the  *
+# * above.                                                                  *
+# *                                                                         *
+# * o Executes a helper program, module, or script to do any of the above.  *
+# *                                                                         *
+# * This list is not exclusive, but is meant to clarify our interpretation  *
+# * of derived works with some common examples.  Other people may interpret *
+# * the plain GPL differently, so we consider this a special exception to   *
+# * the GPL that we apply to Covered Software.  Works which meet any of     *
+# * these conditions must conform to all of the terms of this license,      *
+# * particularly including the GPL Section 3 requirements of providing      *
+# * source code and allowing free redistribution of the work as a whole.    *
+# *                                                                         *
+# * As another special exception to the GPL terms, Insecure.Com LLC grants  *
 # * permission to link the code of this program with any version of the     *
 # * OpenSSL library which is distributed under a license identical to that  *
 # * listed in the included docs/licenses/OpenSSL.txt file, and distribute   *
-# * linked combinations including the two. You must obey the GNU GPL in all *
-# * respects for all of the code used other than OpenSSL.  If you modify    *
-# * this file, you may extend this exception to your version of the file,   *
-# * but you are not obligated to do so.                                     *
+# * linked combinations including the two.                                  *
 # *                                                                         *
-# * If you received these files with a written license agreement or         *
-# * contract stating terms other than the terms above, then that            *
-# * alternative license agreement takes precedence over these comments.     *
+# * Any redistribution of Covered Software, including any derived works,    *
+# * must obey and carry forward all of the terms of this license, including *
+# * obeying all GPL rules and restrictions.  For example, source code of    *
+# * the whole work must be provided and free redistribution must be         *
+# * allowed.  All GPL references to "this License", are to be treated as    *
+# * including the terms and conditions of this license text as well.        *
+# *                                                                         *
+# * Because this license imposes special exceptions to the GPL, Covered     *
+# * Work may not be combined (even as part of a larger work) with plain GPL *
+# * software.  The terms, conditions, and exceptions of this license must   *
+# * be included as well.  This license is incompatible with some other open *
+# * source licenses as well.  In some cases we can relicense portions of    *
+# * Nmap or grant special permissions to use it in other open source        *
+# * software.  Please contact fyodor@nmap.org with any such requests.       *
+# * Similarly, we don't incorporate incompatible open source software into  *
+# * Covered Software without special permission from the copyright holders. *
+# *                                                                         *
+# * If you have any questions about the licensing restrictions on using     *
+# * Nmap in other works, are happy to help.  As mentioned above, we also    *
+# * offer alternative license to integrate Nmap into proprietary            *
+# * applications and appliances.  These contracts have been sold to dozens  *
+# * of software vendors, and generally include a perpetual license as well  *
+# * as providing for priority support and updates.  They also fund the      *
+# * continued development of Nmap.  Please email sales@nmap.com for further *
+# * information.                                                            *
+# *                                                                         *
+# * If you have received a written license agreement or contract for        *
+# * Covered Software stating terms other than these, you may choose to use  *
+# * and redistribute Covered Software under those terms instead of these.   *
 # *                                                                         *
 # * Source is provided to this software because we believe users have a     *
 # * right to know exactly what a program is going to do before they run it. *
-# * This also allows you to audit the software for security holes (none     *
-# * have been found so far).                                                *
+# * This also allows you to audit the software for security holes.          *
 # *                                                                         *
 # * Source code also allows you to port Nmap to new platforms, fix bugs,    *
 # * and add new features.  You are highly encouraged to send your changes   *
-# * to nmap-dev@insecure.org for possible incorporation into the main       *
-# * distribution.  By sending these changes to Fyodor or one of the         *
+# * to the dev@nmap.org mailing list for possible incorporation into the    *
+# * main distribution.  By sending these changes to Fyodor or one of the    *
 # * Insecure.Org development mailing lists, or checking them into the Nmap  *
 # * source code repository, it is understood (unless you specify otherwise) *
 # * that you are offering the Nmap Project (Insecure.Com LLC) the           *
@@ -82,10 +113,9 @@
 # *                                                                         *
 # * This program is distributed in the hope that it will be useful, but     *
 # * WITHOUT ANY WARRANTY; without even the implied warranty of              *
-# * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU       *
-# * General Public License v2.0 for more details at                         *
-# * http://www.gnu.org/licenses/gpl-2.0.html , or in the COPYING file       *
-# * included with Nmap.                                                     *
+# * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the Nmap      *
+# * license file for more details (it's in a COPYING file included with     *
+# * Nmap, and also available from https://svn.nmap.org/nmap/COPYING)        *
 # *                                                                         *
 # ***************************************************************************/
 
@@ -103,12 +133,14 @@ import gobject
 
 from gtkutils import gobject_register
 
+
 class HIGSpinnerImages:
     def __init__(self):
         """This class holds list of GDK Pixbuffers.
 
         - static_pixbufs is used for multiple static pixbuffers
-        - self.animated_pixbufs is used for the pixbuffers that make up the animation
+        - self.animated_pixbufs is used for the pixbuffers that make up the
+          animation
         """
 
         dprint('HIGSpinnerImages::__init__')
@@ -151,14 +183,14 @@ class HIGSpinnerImages:
 
         dprint('HIGSpinnerImages::set_rest_pixbuf')
 
-        if not self.static_pixbufs.has_key(name):
+        if name not in self.static_pixbufs:
             raise StaticPixbufNotFound
 
-        # self.rest_pixbuf holds the *real* pixbuf, not it's name
+        # self.rest_pixbuf holds the *real* pixbuf, not its name
         self.rest_pixbuf = self.static_pixbufs[name]
 
     def set_size(self, width, height):
-        """Sets the size of eache pixbuf (static and animated)"""
+        """Sets the size of each pixbuf (static and animated)"""
         new_animated = []
         for p in self.animated_pixbufs:
             new_animated.append(p.scale_simple(width, height,
@@ -166,15 +198,11 @@ class HIGSpinnerImages:
         self.animated_pixbufs = new_animated
 
         for k in self.static_pixbufs:
-            self.static_pixbufs[k] = self.static_pixbufs[k].\
-                                     scale_simple(width,
-                                                  height,
-                                                  gtk.gdk.INTERP_BILINEAR)
+            self.static_pixbufs[k] = self.static_pixbufs[k].scale_simple(
+                    width, height, gtk.gdk.INTERP_BILINEAR)
 
-        self.rest_pixbuf = self.rest_pixbuf.\
-                           scale_simple(width,
-                                        height,
-                                        gtk.gdk.INTERP_BILINEAR)
+        self.rest_pixbuf = self.rest_pixbuf.scale_simple(
+                width, height, gtk.gdk.INTERP_BILINEAR)
 
         self.images_width = width
         self.images_height = height
@@ -207,17 +235,17 @@ class HIGSpinnerCache:
         """Loads an animated icon by doing a lookup on the icon theme."""
 
         # If user do not choose a icon_name, use the default one
-        if icon_name == None:
+        if icon_name is None:
             icon_name = self.default_animated_icon_name
 
         # Even the default one (now on icon_name) might not be available
-        if icon_name == None:
+        if icon_name is None:
             raise AnimatedIconNotFound
 
         # Try to lookup the icon
         icon_info = self.icon_theme.lookup_icon(icon_name, -1, 0)
         # Even if icon_name exists, it might not be found by lookup
-        if icon_info == None:
+        if icon_info is None:
             raise AnimatedIconNotFound
 
         # Base size is, according to PyGTK docs:
@@ -243,8 +271,8 @@ class HIGSpinnerCache:
 
         for x in range(0, grid_width, size):
             for y in range(0, grid_height, size):
-                self.spinner_images.add_animated_pixbuf(\
-                    self.__extract_frame(grid_pixbuf, x, y, size, size))
+                self.spinner_images.add_animated_pixbuf(
+                        self.__extract_frame(grid_pixbuf, x, y, size, size))
 
     def load_static_from_lookup(self, icon_name="gnome-spinner-rest",
                                 key_name=None):
@@ -258,7 +286,7 @@ class HIGSpinnerCache:
     def load_static_from_filename(self, filename, key_name=None):
         icon_pixbuf = gtk.gdk.pixbuf_new_from_file(filename)
 
-        if key_name == None:
+        if key_name is None:
             key_name = filename.split(".")[0]
 
         self.spinner_images.add_static_pixbuf(key_name, icon_pixbuf)
@@ -291,6 +319,7 @@ class HIGSpinnerCache:
         self.spinner_images.static_pixbufs[key_name].save(path_name,
                                                           image_format)
 
+
 class HIGSpinner(gtk.EventBox):
     """Simple spinner, such as the one found in webbrowsers and file managers.
 
@@ -300,8 +329,8 @@ class HIGSpinner(gtk.EventBox):
     * height, the height that will be set for the images
     """
 
-    __gsignals__ = { 'expose-event' : 'override',
-                     'size-request' : 'override' }
+    __gsignals__ = {'expose-event': 'override',
+                    'size-request': 'override'}
 
     def __init__(self):
         gtk.EventBox.__init__(self)
@@ -315,11 +344,11 @@ class HIGSpinner(gtk.EventBox):
         self.images_width = 32
         self.images_height = 32
 
-        # Timeout set to 100 miliseconds per frame, just as the
+        # Timeout set to 100 milliseconds per frame, just as the
         # Nautilus/Epiphany implementation
         self.timeout = 120
 
-        # Initialize a cache for ouselves
+        # Initialize a cache for ourselves
         self.cache = HIGSpinnerCache()
         self.cache.load_static_from_lookup()
         self.cache.load_animated_from_lookup()
@@ -353,8 +382,8 @@ class HIGSpinner(gtk.EventBox):
         if self.timer_task == 0:
             self.current_pixbuf = self.cache.spinner_images.rest_pixbuf
         else:
-            self.current_pixbuf = self.cache.spinner_images.animated_pixbufs\
-                                  [self.animated_pixbuf_index]
+            self.current_pixbuf = self.cache.spinner_images.animated_pixbufs[
+                    self.animated_pixbuf_index]
 
     def start(self):
         """Starts the animation"""
@@ -370,11 +399,11 @@ class HIGSpinner(gtk.EventBox):
         self.timer_task = 0
         self.queue_draw()
 
-
     def stop(self):
         """Stops the animation
 
-        Do the same stuff as pause, but returns the animation to the beggining."""
+        Do the same stuff as pause, but returns the animation to the
+        beginning."""
         self.pause()
         self.animated_pixbuf_index = 0
 
@@ -386,7 +415,7 @@ class HIGSpinner(gtk.EventBox):
     def do_expose_event(self, event):
         #self.chain(event)
 
-        if self.cache.spinner_images.rest_pixbuf == None:
+        if self.cache.spinner_images.rest_pixbuf is None:
             raise RestPixbufNotFound
 
         self.__select_pixbuf()
@@ -403,7 +432,7 @@ class HIGSpinner(gtk.EventBox):
         dest = event.area.intersect(pix_area)
 
         # If a graphic context doesn't not exist yet, create one
-        if self.gc == None:
+        if self.gc is None:
             self.gc = gtk.gdk.GC(self.window)
         #gc = self.gc
 
